=======
History
=======

0.5.0a0 (2020-10-01)
--------------------

* First release on PyPI.

0.5.0a1 (2020-12-09)
--------------------

* Fix bug that caused Questions to crash when two or more panels were used in
  one form.

* Add feature for creating Form subclasses from JSON data.

* Add screencast to README page.

* Update docs.

* Update dependencies to lastest versions.

0.5.0a2 (2020-12-09)
--------------------

* Fix bug with form parameters in from_json conversion.
